@@ -5,8 +5,7 @@
 : ${MARKDOWN_CMD:=markdown}
 : ${MARKDOWN_OPTS:= }
 
-echo test |eval $MARKDOWN_CMD > "$SCRATCH_FILE".plugin_devnull 2>&1 &&
-	MARKDOWN_INPATH=true
+nb_eval "$MARKDOWN_CMD" && MARKDOWN_INPATH=true
 	
 if [ "$MARKDOWN_INPATH" = "true" ]; then
 	# nb_msg "$plugins_entryfilteraction `basename $nb_plugin` ..."
