@@ -8,13 +8,12 @@ fdlinksprev_cat_arch="$cat_arch"
 
 # Atom 1.0
 if [ ! -z "$NB_AtomVer" ]; then
-	if [ "$MKPAGE_TEMPLATE" = "$NB_TEMPLATE_DIR/$CATEGORY_TEMPLATE" ]; then
+	NB_AtomLink="${BASE_URL}atom.$NB_SYND_FILETYPE"
+	NB_AtomTitle="Atom $NB_AtomVer"
+	if [ "$MKPAGE_TEMPLATE" = "$NB_TEMPLATE_DIR/$CATEGORY_TEMPLATE" ] && [[ "$CATEGORY_FEEDS" = 1 && "$ATOM_CATFEEDS" = 1 ]]; then
 		NB_AtomCatFile="${category_file//[\.]$NB_FILETYPE/-atom.$NB_SYND_FILETYPE}"
 		NB_AtomLink="${ARCHIVES_PATH}$NB_AtomCatFile"
 		NB_AtomTitle="Atom $NB_AtomVer: $NB_ArchiveTitle"
-	else
-		NB_AtomLink="${BASE_URL}atom.$NB_SYND_FILETYPE"
-		NB_AtomTitle="Atom $NB_AtomVer"
 	fi
 	NB_AtomAltLink=$(
 	cat <<-EOF
@@ -28,13 +27,12 @@ fi
 
 # RSS 2.0
 if [ ! -z "$NB_RSS2Ver" ]; then
-	if [ "$MKPAGE_TEMPLATE" = "$NB_TEMPLATE_DIR/$CATEGORY_TEMPLATE" ]; then
+	NB_RSS2Link="${BASE_URL}rss.$NB_SYND_FILETYPE"
+	NB_RSS2Title="RSS $NB_RSS2Ver"
+	if [ "$MKPAGE_TEMPLATE" = "$NB_TEMPLATE_DIR/$CATEGORY_TEMPLATE" ] && [[ "$CATEGORY_FEEDS" = 1 && "$RSS2_CATFEEDS" = 1 ]]; then
 		NB_RSS2CatFile="${category_file//[\.]$NB_FILETYPE/-rss.$NB_SYND_FILETYPE}"
 		NB_RSS2Link="${ARCHIVES_PATH}$NB_RSS2CatFile"
 		NB_RSS2Title="RSS $NB_RSS2Ver: $NB_ArchiveTitle"
-	else
-		NB_RSS2Link="${BASE_URL}rss.$NB_SYND_FILETYPE"
-		NB_RSS2Title="RSS $NB_RSS2Ver"
 	fi
 	NB_RSS2AltLink=$(
 	cat <<-EOF
@@ -48,14 +46,13 @@ fi
 
 # RSS 1.0
 if [ ! -z "$NB_RSSVer" ]; then
-	if [ "$MKPAGE_TEMPLATE" = "$NB_TEMPLATE_DIR/$CATEGORY_TEMPLATE" ]; then
+	NB_RSSLink="${BASE_URL}index.$NB_SYND_FILETYPE"
+	NB_RSSTitle="RSS $NB_RSSVer"
+	if [ "$MKPAGE_TEMPLATE" = "$NB_TEMPLATE_DIR/$CATEGORY_TEMPLATE" ] && [[ "$CATEGORY_FEEDS" = 1 && "$RSS_CATFEEDS" = 1 ]]; then
 		NB_RSSCatFile=`chg_suffix "$category_file" $NB_SYND_FILETYPE`
 		NB_RSSLink="${ARCHIVES_PATH}$NB_RSSCatFile"
 		NB_RSSTitle="RSS $NB_RSSVer: $NB_ArchiveTitle"
-	else
-		NB_RSSLink="${BASE_URL}index.$NB_SYND_FILETYPE"
-		NB_RSSTitle="RSS $NB_RSSVer"
-	fi
+	fi	
 	NB_RSSAltLink=$(
 	cat <<-EOF
 		<link rel="alternate" type="application/rss+xml"
